@@ -32,7 +32,9 @@ import magic
 import pdfplumber
 from PyPDF2 import PdfFileReader, PdfFileWriter
 import io
+from urllib.parse import quote
 from scrapy.http.headers import Headers
+
 # logging.basicConfig(level=logging.INFO)
 logging.getLogger('pdfplumber').setLevel(logging.WARNING)
 logging.getLogger('PyPDF2').setLevel(logging.WARNING)
@@ -268,6 +270,9 @@ class OssFilesPipeline(MediaPipeline):
                 if ItemAdapter(item).get(self.file_pipe_config.get(self.__class__.__name__)["FILES_OSS_URLS_FIELD" ], '') else []
             def request_add_params(urls):
                 for u in urls:
+                    if '%' not in u:
+                        #防止资源链接出现空格等特殊字符,eg:https://www.semiee.com/file/Infineon/Infineon-TLE9261-3BQX V33.pdf
+                        u = quote(u, safe='/:') 
                     u = Request(u)
                     if item._header: 
                         # 配置资源链接上一请求的header和referer,
@@ -297,7 +302,8 @@ class OssFilesPipeline(MediaPipeline):
     def item_completed(self, results, item, info):
         if self.file_pipe_config.get(self.__class__.__name__)["RESOURCE_CLASSNAME"].lower() in item.__class__.__name__.lower():
             with suppress(TypeError):
-                ItemAdapter(item)[self.file_pipe_config.get(self.__class__.__name__)['FILES_OSS_RESULT_FIELD']] = '|'.join([x['path'] for ok, x in results if ok])
+                if '|'.join([x['path'] for ok, x in results if ok]):
+                    ItemAdapter(item)[self.file_pipe_config.get(self.__class__.__name__)['FILES_OSS_RESULT_FIELD']] = '|'.join([x['path'] for ok, x in results if ok])
             # TAG: 如果决定资源字段返回为空不存表,修改 FILTER_EMPTY_ITEM = True , 默认false
             with suppress(KeyError):
                 if not item[self.file_pipe_config.get(self.__class__.__name__)["FILES_OSS_RESULT_FIELD"]] and self.filter_empty_item:
